import React, { useEffect, useState } from "react";
import ProductTable from "./ProductTable.jsx";
import Config from "../config.js";
import { Link } from "react-router-dom";

export default function ProductIndex() {
  const [products, setProducts] = useState([]);
  const [displayProducts, setDisplayProducts] = useState([]);
  const [categories, setCategories] = useState([]);
  const [activeCategory, setActiveCategory] = useState("");

  console.log(displayProducts);
  const fetchProducts = async () => {
    const res = await fetch(`${Config.inventoryUrl}`);
    if (res.ok) {
      const data = await res.json();
      setProducts([...data]);
      setDisplayProducts([...data]);
      setCategories([
        ...data.reduce((acc, prod) => {
          if (!acc.includes(prod.category)) {
            acc.push(prod.category);
          }
          return acc;
        }, []),
      ]);
    }
  };

  useEffect(() => fetchProducts(), []);

  return (
    <div className="container flex-column d-flex justify-content-center">
      <div className="container mt-3 d-flex justify-content-between align-items-center">
        <h1 id="title" className="text-center">
          Inventory
        </h1>
        <Link type="link" className="btn btn-success" to="/products/new">
          + New Product
        </Link>
      </div>
      {products.length > 0 ? (
        <>
            <select
              className="form-select w-25 mt-1"
              id="category-select"
              onChange={(e) => {
                if (e.target.value === "") {
                  setDisplayProducts([...products]);
                  return;
                }
                const filtered = products.filter(
                  (prod) => prod.category === e.target.value
                );
                setDisplayProducts([...filtered]);
              }}
            >
              <option value="">Select Category</option>
              {categories.map((category, i) => (
                <option key={i + 679}>{category}</option>
              ))}
            </select>
          <ProductTable
            productData={displayProducts}
            fetchProducts={fetchProducts}
            products={displayProducts}
          />
        </>
      ) : (
        <p>No products found.</p>
      )}
    </div>
  );
}
