import React from "react";
import ProductRow from "./ProductRow.jsx";
import { Table } from "react-bootstrap";
import { deleteProduct } from "../actions/apiRequests";
import { withRouter } from "react-router";

class SearchResults extends React.Component {

  constructor(props) {
    super(props);
    this.state = {
      results: this.props.history.location.state.results
    }
    this.handleDelete = this.handleDelete.bind(this);
  }

   handleDelete(sku){
     deleteProduct(sku)
      .then(() => {
        const newResults = this.state.results.filter(product => product.sku !== sku);
        this.setState({results: newResults});
        this.props.history.push("/searchResults", this.state);
      });
  }

  render() {
    return (
      <div className="container flex-column d-flex justify-content-center">
        <h1 id="title" className="text-center" >Search Results</h1>
        {this.state.results.length > 0 ?
          <Table>
            <thead>
              <tr>
                <th>SKU</th>
                <th>Product Name</th>
                <th>Price</th>
                <th>Category</th>
                <th>Available Stock</th>
                <th>Blocked Stock</th>
                <th>Fulfilled Stock</th>
              </tr>
            </thead>
            <tbody>
              {this.state.results.map((product) => {
                return (
                  <ProductRow key={product.sku} product={product} handleDelete={() => this.handleDelete(product.sku)} />
                );
              })}
            </tbody>
          </Table>
          :
          <p>Unable to find any matching products.</p>
        }
      </div>
    );
  }

}

export default withRouter(SearchResults);